# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKStatisticsPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkHistogramToProbabilityImageFilterPython
else:
    import _itkHistogramToProbabilityImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkHistogramPython
import itk.itkArrayPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.itkSamplePython
import itk.itkVectorPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkImagePython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkIndexPython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkImageRegionPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython

def itkHistogramToProbabilityImageFilterHDIF2_Superclass_New():
    return itkHistogramToProbabilityImageFilterHDIF2_Superclass.New()

class itkHistogramToProbabilityImageFilterHDIF2_Superclass(itk.itkImageSourcePython.itkImageSourceIF2):
    r"""Proxy of C++ itkHistogramToProbabilityImageFilterHDIF2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramToProbabilityImageFilterHDIF2_Superclass_Pointer"""
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHDIF2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramToProbabilityImageFilterHDIF2_Superclass_Pointer"""
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHDIF2_Superclass_Clone(self)

    def SetInput(self, input):
        r"""
        SetInput(self, input)

        Parameters
        ----------
        input: itkHistogramD const *

        """
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHDIF2_Superclass_SetInput(self, input)

    def GetInput(self):
        r"""GetInput(self) -> itkHistogramD"""
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHDIF2_Superclass_GetInput(self)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Function::HistogramProbabilityFunction< unsigned long > const &

        """
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHDIF2_Superclass_SetFunctor(self, functor)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Function::HistogramProbabilityFunction< unsigned long >
        GetFunctor(self) -> itk::Function::HistogramProbabilityFunction< unsigned long > const &
        """
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHDIF2_Superclass_GetFunctor(self, *args)

    def SetTotalFrequency(self, n):
        r"""
        SetTotalFrequency(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHDIF2_Superclass_SetTotalFrequency(self, n)
    __swig_destroy__ = _itkHistogramToProbabilityImageFilterPython.delete_itkHistogramToProbabilityImageFilterHDIF2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramToProbabilityImageFilterHDIF2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHDIF2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramToProbabilityImageFilterHDIF2_Superclass

        Create a new object of the class itkHistogramToProbabilityImageFilterHDIF2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramToProbabilityImageFilterHDIF2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramToProbabilityImageFilterHDIF2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramToProbabilityImageFilterHDIF2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramToProbabilityImageFilterHDIF2_Superclass in _itkHistogramToProbabilityImageFilterPython:
_itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHDIF2_Superclass_swigregister(itkHistogramToProbabilityImageFilterHDIF2_Superclass)

def itkHistogramToProbabilityImageFilterHDIF3_Superclass_New():
    return itkHistogramToProbabilityImageFilterHDIF3_Superclass.New()

class itkHistogramToProbabilityImageFilterHDIF3_Superclass(itk.itkImageSourcePython.itkImageSourceIF3):
    r"""Proxy of C++ itkHistogramToProbabilityImageFilterHDIF3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramToProbabilityImageFilterHDIF3_Superclass_Pointer"""
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHDIF3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramToProbabilityImageFilterHDIF3_Superclass_Pointer"""
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHDIF3_Superclass_Clone(self)

    def SetInput(self, input):
        r"""
        SetInput(self, input)

        Parameters
        ----------
        input: itkHistogramD const *

        """
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHDIF3_Superclass_SetInput(self, input)

    def GetInput(self):
        r"""GetInput(self) -> itkHistogramD"""
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHDIF3_Superclass_GetInput(self)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Function::HistogramProbabilityFunction< unsigned long > const &

        """
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHDIF3_Superclass_SetFunctor(self, functor)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Function::HistogramProbabilityFunction< unsigned long >
        GetFunctor(self) -> itk::Function::HistogramProbabilityFunction< unsigned long > const &
        """
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHDIF3_Superclass_GetFunctor(self, *args)

    def SetTotalFrequency(self, n):
        r"""
        SetTotalFrequency(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHDIF3_Superclass_SetTotalFrequency(self, n)
    __swig_destroy__ = _itkHistogramToProbabilityImageFilterPython.delete_itkHistogramToProbabilityImageFilterHDIF3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramToProbabilityImageFilterHDIF3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHDIF3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramToProbabilityImageFilterHDIF3_Superclass

        Create a new object of the class itkHistogramToProbabilityImageFilterHDIF3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramToProbabilityImageFilterHDIF3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramToProbabilityImageFilterHDIF3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramToProbabilityImageFilterHDIF3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramToProbabilityImageFilterHDIF3_Superclass in _itkHistogramToProbabilityImageFilterPython:
_itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHDIF3_Superclass_swigregister(itkHistogramToProbabilityImageFilterHDIF3_Superclass)

def itkHistogramToProbabilityImageFilterHFIF2_Superclass_New():
    return itkHistogramToProbabilityImageFilterHFIF2_Superclass.New()

class itkHistogramToProbabilityImageFilterHFIF2_Superclass(itk.itkImageSourcePython.itkImageSourceIF2):
    r"""Proxy of C++ itkHistogramToProbabilityImageFilterHFIF2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramToProbabilityImageFilterHFIF2_Superclass_Pointer"""
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHFIF2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramToProbabilityImageFilterHFIF2_Superclass_Pointer"""
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHFIF2_Superclass_Clone(self)

    def SetInput(self, input):
        r"""
        SetInput(self, input)

        Parameters
        ----------
        input: itkHistogramF const *

        """
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHFIF2_Superclass_SetInput(self, input)

    def GetInput(self):
        r"""GetInput(self) -> itkHistogramF"""
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHFIF2_Superclass_GetInput(self)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Function::HistogramProbabilityFunction< unsigned long > const &

        """
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHFIF2_Superclass_SetFunctor(self, functor)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Function::HistogramProbabilityFunction< unsigned long >
        GetFunctor(self) -> itk::Function::HistogramProbabilityFunction< unsigned long > const &
        """
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHFIF2_Superclass_GetFunctor(self, *args)

    def SetTotalFrequency(self, n):
        r"""
        SetTotalFrequency(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHFIF2_Superclass_SetTotalFrequency(self, n)
    __swig_destroy__ = _itkHistogramToProbabilityImageFilterPython.delete_itkHistogramToProbabilityImageFilterHFIF2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramToProbabilityImageFilterHFIF2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHFIF2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramToProbabilityImageFilterHFIF2_Superclass

        Create a new object of the class itkHistogramToProbabilityImageFilterHFIF2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramToProbabilityImageFilterHFIF2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramToProbabilityImageFilterHFIF2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramToProbabilityImageFilterHFIF2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramToProbabilityImageFilterHFIF2_Superclass in _itkHistogramToProbabilityImageFilterPython:
_itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHFIF2_Superclass_swigregister(itkHistogramToProbabilityImageFilterHFIF2_Superclass)

def itkHistogramToProbabilityImageFilterHFIF3_Superclass_New():
    return itkHistogramToProbabilityImageFilterHFIF3_Superclass.New()

class itkHistogramToProbabilityImageFilterHFIF3_Superclass(itk.itkImageSourcePython.itkImageSourceIF3):
    r"""Proxy of C++ itkHistogramToProbabilityImageFilterHFIF3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramToProbabilityImageFilterHFIF3_Superclass_Pointer"""
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHFIF3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramToProbabilityImageFilterHFIF3_Superclass_Pointer"""
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHFIF3_Superclass_Clone(self)

    def SetInput(self, input):
        r"""
        SetInput(self, input)

        Parameters
        ----------
        input: itkHistogramF const *

        """
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHFIF3_Superclass_SetInput(self, input)

    def GetInput(self):
        r"""GetInput(self) -> itkHistogramF"""
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHFIF3_Superclass_GetInput(self)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Function::HistogramProbabilityFunction< unsigned long > const &

        """
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHFIF3_Superclass_SetFunctor(self, functor)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Function::HistogramProbabilityFunction< unsigned long >
        GetFunctor(self) -> itk::Function::HistogramProbabilityFunction< unsigned long > const &
        """
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHFIF3_Superclass_GetFunctor(self, *args)

    def SetTotalFrequency(self, n):
        r"""
        SetTotalFrequency(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHFIF3_Superclass_SetTotalFrequency(self, n)
    __swig_destroy__ = _itkHistogramToProbabilityImageFilterPython.delete_itkHistogramToProbabilityImageFilterHFIF3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramToProbabilityImageFilterHFIF3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHFIF3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramToProbabilityImageFilterHFIF3_Superclass

        Create a new object of the class itkHistogramToProbabilityImageFilterHFIF3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramToProbabilityImageFilterHFIF3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramToProbabilityImageFilterHFIF3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramToProbabilityImageFilterHFIF3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramToProbabilityImageFilterHFIF3_Superclass in _itkHistogramToProbabilityImageFilterPython:
_itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHFIF3_Superclass_swigregister(itkHistogramToProbabilityImageFilterHFIF3_Superclass)

def itkHistogramToProbabilityImageFilterHDIF2_New():
    return itkHistogramToProbabilityImageFilterHDIF2.New()

class itkHistogramToProbabilityImageFilterHDIF2(itkHistogramToProbabilityImageFilterHDIF2_Superclass):
    r"""Proxy of C++ itkHistogramToProbabilityImageFilterHDIF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramToProbabilityImageFilterHDIF2_Pointer"""
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHDIF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramToProbabilityImageFilterHDIF2_Pointer"""
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHDIF2_Clone(self)
    __swig_destroy__ = _itkHistogramToProbabilityImageFilterPython.delete_itkHistogramToProbabilityImageFilterHDIF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramToProbabilityImageFilterHDIF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHDIF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramToProbabilityImageFilterHDIF2

        Create a new object of the class itkHistogramToProbabilityImageFilterHDIF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramToProbabilityImageFilterHDIF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramToProbabilityImageFilterHDIF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramToProbabilityImageFilterHDIF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramToProbabilityImageFilterHDIF2 in _itkHistogramToProbabilityImageFilterPython:
_itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHDIF2_swigregister(itkHistogramToProbabilityImageFilterHDIF2)

def itkHistogramToProbabilityImageFilterHDIF3_New():
    return itkHistogramToProbabilityImageFilterHDIF3.New()

class itkHistogramToProbabilityImageFilterHDIF3(itkHistogramToProbabilityImageFilterHDIF3_Superclass):
    r"""Proxy of C++ itkHistogramToProbabilityImageFilterHDIF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramToProbabilityImageFilterHDIF3_Pointer"""
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHDIF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramToProbabilityImageFilterHDIF3_Pointer"""
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHDIF3_Clone(self)
    __swig_destroy__ = _itkHistogramToProbabilityImageFilterPython.delete_itkHistogramToProbabilityImageFilterHDIF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramToProbabilityImageFilterHDIF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHDIF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramToProbabilityImageFilterHDIF3

        Create a new object of the class itkHistogramToProbabilityImageFilterHDIF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramToProbabilityImageFilterHDIF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramToProbabilityImageFilterHDIF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramToProbabilityImageFilterHDIF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramToProbabilityImageFilterHDIF3 in _itkHistogramToProbabilityImageFilterPython:
_itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHDIF3_swigregister(itkHistogramToProbabilityImageFilterHDIF3)

def itkHistogramToProbabilityImageFilterHFIF2_New():
    return itkHistogramToProbabilityImageFilterHFIF2.New()

class itkHistogramToProbabilityImageFilterHFIF2(itkHistogramToProbabilityImageFilterHFIF2_Superclass):
    r"""Proxy of C++ itkHistogramToProbabilityImageFilterHFIF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramToProbabilityImageFilterHFIF2_Pointer"""
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHFIF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramToProbabilityImageFilterHFIF2_Pointer"""
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHFIF2_Clone(self)
    __swig_destroy__ = _itkHistogramToProbabilityImageFilterPython.delete_itkHistogramToProbabilityImageFilterHFIF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramToProbabilityImageFilterHFIF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHFIF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramToProbabilityImageFilterHFIF2

        Create a new object of the class itkHistogramToProbabilityImageFilterHFIF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramToProbabilityImageFilterHFIF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramToProbabilityImageFilterHFIF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramToProbabilityImageFilterHFIF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramToProbabilityImageFilterHFIF2 in _itkHistogramToProbabilityImageFilterPython:
_itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHFIF2_swigregister(itkHistogramToProbabilityImageFilterHFIF2)

def itkHistogramToProbabilityImageFilterHFIF3_New():
    return itkHistogramToProbabilityImageFilterHFIF3.New()

class itkHistogramToProbabilityImageFilterHFIF3(itkHistogramToProbabilityImageFilterHFIF3_Superclass):
    r"""Proxy of C++ itkHistogramToProbabilityImageFilterHFIF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramToProbabilityImageFilterHFIF3_Pointer"""
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHFIF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramToProbabilityImageFilterHFIF3_Pointer"""
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHFIF3_Clone(self)
    __swig_destroy__ = _itkHistogramToProbabilityImageFilterPython.delete_itkHistogramToProbabilityImageFilterHFIF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramToProbabilityImageFilterHFIF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHFIF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramToProbabilityImageFilterHFIF3

        Create a new object of the class itkHistogramToProbabilityImageFilterHFIF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramToProbabilityImageFilterHFIF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramToProbabilityImageFilterHFIF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramToProbabilityImageFilterHFIF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramToProbabilityImageFilterHFIF3 in _itkHistogramToProbabilityImageFilterPython:
_itkHistogramToProbabilityImageFilterPython.itkHistogramToProbabilityImageFilterHFIF3_swigregister(itkHistogramToProbabilityImageFilterHFIF3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def histogram_to_probability_image_filter(*args,  functor=..., total_frequency: int=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for HistogramToProbabilityImageFilter"""
    import itk

    kwarg_typehints = { 'functor':functor,'total_frequency':total_frequency }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.HistogramToProbabilityImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def histogram_to_probability_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKStatistics.HistogramToProbabilityImageFilter
    histogram_to_probability_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    histogram_to_probability_image_filter.__doc__ = filter_object.__doc__

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def histogram_to_image_filter(*args,  functor=..., total_frequency: int=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for HistogramToImageFilter"""
    import itk

    kwarg_typehints = { 'functor':functor,'total_frequency':total_frequency }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.HistogramToImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def histogram_to_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKStatistics.HistogramToImageFilter
    histogram_to_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    histogram_to_image_filter.__doc__ = filter_object.__doc__



